@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,24 +13,22 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple, Union
+import warnings
 
-from google.api_core import grpc_helpers
-from google.api_core import operations_v1
-from google.api_core import gapic_v1
+from google.api import httpbody_pb2  # type: ignore
+from google.api_core import gapic_v1, grpc_helpers, operations_v1
 import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-
+from google.longrunning import operations_pb2  # type: ignore
 import grpc  # type: ignore
 
-from google.api import httpbody_pb2  # type: ignore
-from google.cloud.recommendationengine_v1beta1.types import import_
 from google.cloud.recommendationengine_v1beta1.types import user_event as gcr_user_event
+from google.cloud.recommendationengine_v1beta1.types import import_
 from google.cloud.recommendationengine_v1beta1.types import user_event_service
-from google.longrunning import operations_pb2  # type: ignore
-from .base import UserEventServiceTransport, DEFAULT_CLIENT_INFO
+
+from .base import DEFAULT_CLIENT_INFO, UserEventServiceTransport
 
 
 class UserEventServiceGrpcTransport(UserEventServiceTransport):
@@ -70,7 +68,7 @@ class UserEventServiceGrpcTransport(UserEventServiceTransport):
 
         Args:
             host (Optional[str]):
-                 The hostname to connect to.
+                 The hostname to connect to (default: 'recommendationengine.googleapis.com').
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -285,6 +283,7 @@ class UserEventServiceGrpcTransport(UserEventServiceTransport):
         Writes a single user event from the browser. This
         uses a GET request to due to browser restriction of
         POST-ing to a 3rd party domain.
+
         This method is used only by the Recommendations AI
         JavaScript pixel. Users should not call this method
         directly.
@@ -378,6 +377,7 @@ class UserEventServiceGrpcTransport(UserEventServiceTransport):
         Bulk import of User events. Request processing might
         be synchronous. Events that already exist are skipped.
         Use this method for backfilling historical user events.
+
         Operation.response is of type ImportResponse. Note that
         it is possible for a subset of the items to be
         successfully inserted. Operation.metadata is of type
